% ----------------------
% Goddard Rocket Problem
% ----------------------
% This problem is taken from the following reference:
% http://www.mcs.anl.gov/~more/cops/bcops/rocket.html
clear setup limits guess

h0 = 0;
v0 = 0;
m0 = 3;
mf = 1;

hmin = 0;
hmax = 30000;
vmin = -1500;
vmax = 1500;
mmin = 0.2*m0;
mmax = m0;
t0 = 0;
tfMin = 0;
tfMax = 500;

global CONSTANTS
CONSTANTS.g0 = 32.174;
CONSTANTS.rho0 = 0.002378;
CONSTANTS.H = 23800;
CONSTANTS.csqrd = 3.264*CONSTANTS.g0*CONSTANTS.H;
% CONSTANTS.sigma = 5.4915e-5;
% CONSTANTS.c = 1580.9425;
CONSTANTS.c = sqrt(CONSTANTS.csqrd);
Tmax = 2*m0*CONSTANTS.g0;
CONSTANTS.dragk = 0.7110*Tmax/CONSTANTS.csqrd;

%  mf = CONSTANTS.mc*m0;

iphase = 1;
limits(iphase).nodes = 5;
limits(iphase).time.min = [t0 tfMin];
limits(iphase).time.max = [t0 tfMax];
limits(iphase).state.min(1,:)   = [h0 hmin hmin];
limits(iphase).state.max(1,:)   = [h0 hmax hmax];
limits(iphase).state.min(2,:)   = [v0 vmin vmin];
limits(iphase).state.max(2,:)   = [v0 vmax vmax];
limits(iphase).state.min(3,:)   = [m0 mmin mmin];
limits(iphase).state.max(3,:)   = [m0 mmax mmax];
limits(iphase).control.min(1,:) = 0;
limits(iphase).control.max(1,:) = Tmax;
limits(iphase).parameter.min    = [];
limits(iphase).parameter.max    = [];
limits(iphase).path.min    = [];
limits(iphase).path.max    = [];
limits(iphase).event.min   = [];
limits(iphase).event.max   = [];
guess(iphase).time =  [tfMin; tfMax];
guess(iphase).state(:,1) = [h0; h0];
guess(iphase).state(:,2) = [v0; v0];
guess(iphase).state(:,3) = [m0; mf];
guess(iphase).control(:,1) = [Tmax; Tmax];
guess(iphase).parameter = [];

iphase = 2;
limits(iphase).nodes = 5;
limits(iphase).time.min = [tfMin tfMin];
limits(iphase).time.max = [tfMax tfMax];
limits(iphase).state.min(1,:)   = [hmin hmin hmin];
limits(iphase).state.max(1,:)   = [hmax hmax hmax];
limits(iphase).state.min(2,:)   = [vmin vmin vmin];
limits(iphase).state.max(2,:)   = [vmax vmax vmax];
limits(iphase).state.min(3,:)   = [mmin mmin mmin];
limits(iphase).state.max(3,:)   = [mmax mmax mmax];
limits(iphase).control.min(1,:) = 0;
limits(iphase).control.max(1,:) = Tmax;
limits(iphase).parameter.min    = [];
limits(iphase).parameter.max    = [];
limits(iphase).path.min    = [];
limits(iphase).path.max    = [];
limits(iphase).path.min    = 0;
limits(iphase).path.max    = 0;
limits(iphase).event.min   = [0];
limits(iphase).event.max   = [0];
guess(iphase).time =  [tfMin; tfMax];
guess(iphase).state(:,1) = [hmax; hmax];
guess(iphase).state(:,2) = [vmax; vmax];
guess(iphase).state(:,3) = [m0; mf];
guess(iphase).control(:,1) = [Tmax; Tmax];
guess(iphase).parameter = [];

iphase = 3;
limits(iphase).nodes = 5;
limits(iphase).time.min = [tfMin tfMin];
limits(iphase).time.max = [tfMax tfMax];
limits(iphase).state.min(1,:)   = [hmin hmin hmin];
limits(iphase).state.max(1,:)   = [hmax hmax hmax];
limits(iphase).state.min(2,:)   = [vmin vmin vmin];
limits(iphase).state.max(2,:)   = [vmax vmax vmax];
limits(iphase).state.min(3,:)   = [mmin mmin mf];
limits(iphase).state.max(3,:)   = [mmax mmax mf];
limits(iphase).control.min(1,:) = 0;
limits(iphase).control.max(1,:) = Tmax;
limits(iphase).parameter.min    = [];
limits(iphase).parameter.max    = [];
limits(iphase).path.min    = [];
limits(iphase).path.max    = [];
limits(iphase).event.min   = [];
limits(iphase).event.max   = [];
guess(iphase).time =  [tfMin; tfMax];
guess(iphase).state(:,1) = [hmax; hmax];
guess(iphase).state(:,2) = [vmax; vmax];
guess(iphase).state(:,3) = [m0; mf];
guess(iphase).control(:,1) = [Tmax; Tmax];
guess(iphase).parameter = [];

ipair = 1;
linkages(ipair).left.phase = 1;
linkages(ipair).right.phase = 2;
linkages(ipair).min = [0; 0; 0];
linkages(ipair).max = [0; 0; 0];

ipair = 2;
linkages(ipair).left.phase = 2;
linkages(ipair).right.phase = 3;
linkages(ipair).min = [0; 0; 0];
linkages(ipair).max = [0; 0; 0];

setup.name = 'Goddard-Rocket';
setup.funcs.cost = 'goddardRocketCost';
setup.funcs.dae = 'goddardRocketDae';
setup.funcs.event = 'goddardRocketEvent';
setup.funcs.link = 'goddardRocketLink';
setup.limits = limits;
setup.derivatives = 'automatic';
setup.guess = guess;
setup.linkages = linkages;
setup.autoscale = 'on';
output = gpops(setup);
solution = output.solution;

if 0,
load socssolution.dat;
ss = socssolution;
indices_socs_phase1 = 1:28;
indices_socs_phase2 = 29:101;
indices_socs_phase3 = 102:140;
ss(indices_socs_phase3,3) = ss(indices_socs_phase3,3)*6076.115;
socstime1 = ss(indices_socs_phase1,2);
socstime2 = ss(indices_socs_phase2,2);
socstime3 = ss(indices_socs_phase3,2);
socsstate1 = ss(indices_socs_phase1,3:5);
socsstate2 = ss(indices_socs_phase2,3:5);
socsstate3 = ss(indices_socs_phase3,3:5);
socscontrol1 = ss(indices_socs_phase1,6);
socscontrol2 = ss(indices_socs_phase2,6);
socscontrol3 = ss(indices_socs_phase3,6);

gpopstime1 = solution(1).time;
gpopstime2 = solution(2).time;
gpopstime3 = solution(3).time;
gpopsstate1 = solution(1).state;
gpopsstate2 = solution(2).state;
gpopsstate3 = solution(3).state;
gpopscontrol1 = solution(1).control_extrap;
gpopscontrol2 = solution(2).control_extrap;
gpopscontrol3 = solution(3).control_extrap;

figure(1);
pp = plot(gpopstime1,gpopsstate1(:,1)/1000,'bo',socstime1,socsstate1(:,1)/1000,'-r',gpopstime2,gpopsstate2(:,1)/1000,'bo',socstime2,socsstate2(:,1)/1000,'-r',gpopstime3,gpopsstate3(:,1)/1000,'bo',socstime3,socsstate3(:,1)/1000,'-r');
xl = xlabel('time');
yl = ylabel('altitude');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardAlt_5Nodes.eps

figure(2);
pp = plot(gpopstime1,gpopsstate1(:,2),'bo',socstime1,socsstate1(:,2),'-r',gpopstime2,gpopsstate2(:,2),'bo',socstime2,socsstate2(:,2),'-r',gpopstime3,gpopsstate3(:,2),'bo',socstime3,socsstate3(:,2),'-r');
xl = xlabel('time');
yl = ylabel('velocity');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
grid on;
print -depsc2 goddardVel_5Nodes.eps

figure(3);
pp = plot(gpopstime1,gpopsstate1(:,3),'bo',socstime1,socsstate1(:,3),'-r',gpopstime2,gpopsstate2(:,3),'bo',socstime2,socsstate2(:,3),'-r',gpopstime3,gpopsstate3(:,3),'bo',socstime3,socsstate3(:,3),'-r');
xl = xlabel('time');
yl = ylabel('mass');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardMass_5Nodes.eps

figure(4);
pp = plot(gpopstime1,gpopscontrol1,'bo',socstime1,socscontrol1,'-r',gpopstime2,gpopscontrol2,'bo',socstime2,socscontrol2,'-r',gpopstime3,gpopscontrol3,'bo',socstime3,socscontrol3,'-r');
xl = xlabel('time');
yl = ylabel('thrust');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardThrust_5Nodes.eps

setup.guess = solution;
setup.limits(1).nodes = 25;
setup.limits(2).nodes = 25;
setup.limits(3).nodes = 25;
output = gpops(setup);
solution = output.solution;

gpopstime1 = solution(1).time;
gpopstime2 = solution(2).time;
gpopstime3 = solution(3).time;
gpopsstate1 = solution(1).state;
gpopsstate2 = solution(2).state;
gpopsstate3 = solution(3).state;
gpopscontrol1 = solution(1).control_extrap;
gpopscontrol2 = solution(2).control_extrap;
gpopscontrol3 = solution(3).control_extrap;

figure(5);
pp = plot(gpopstime1,gpopsstate1(:,1)/1000,'bo',socstime1,socsstate1(:,1)/1000,'-r',gpopstime2,gpopsstate2(:,1)/1000,'bo',socstime2,socsstate2(:,1)/1000,'-r',gpopstime3,gpopsstate3(:,1)/1000,'bo',socstime3,socsstate3(:,1)/1000,'-r');
xl = xlabel('time');
yl = ylabel('altitude');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardAlt_25Nodes.eps

figure(6);
pp = plot(gpopstime1,gpopsstate1(:,2),'bo',socstime1,socsstate1(:,2),'-r',gpopstime2,gpopsstate2(:,2),'bo',socstime2,socsstate2(:,2),'-r',gpopstime3,gpopsstate3(:,2),'bo',socstime3,socsstate3(:,2),'-r');
xl = xlabel('time');
yl = ylabel('velocity');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
grid on;
print -depsc2 goddardVel_25Nodes.eps

figure(7);
pp = plot(gpopstime1,gpopsstate1(:,3),'bo',socstime1,socsstate1(:,3),'-r',gpopstime2,gpopsstate2(:,3),'bo',socstime2,socsstate2(:,3),'-r',gpopstime3,gpopsstate3(:,3),'bo',socstime3,socsstate3(:,3),'-r');
xl = xlabel('time');
yl = ylabel('mass');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardMass_25Nodes.eps

figure(8);
pp = plot(gpopstime1,gpopscontrol1,'bo',socstime1,socscontrol1,'-r',gpopstime2,gpopscontrol2,'bo',socstime2,socscontrol2,'-r',gpopstime3,gpopscontrol3,'bo',socstime3,socscontrol3,'-r');
xl = xlabel('time');
yl = ylabel('thrust');
ll = legend('GPOPS Solution','SOCS Solution','Location','Best');
set(pp,'LineWidth',2);
set(xl,'FontName','Times','FontSize',18);
set(yl,'FontName','Times','FontSize',18);
set(ll,'FontName','Times','FontSize',18);
set(gca,'FontName','Times','FontSize',18);
grid on;
print -depsc2 goddardThrust_25Nodes.eps
end;
